package de.jalin.ldapadmin.beans;

import java.io.Serializable;
import java.security.NoSuchAlgorithmException;
import java.util.ArrayList;
import java.util.List;

import de.jalin.ldapadmin.ldap.PasswordValidator;
import de.jalin.ldapadmin.ldap.SimplePasswordException;

public class User implements Serializable, LDAPBean {

    private static final long serialVersionUID = 1L;

    private String dn;
    private String login;
    private String password;
    private String firstname;
    private String lastname;
    private String displayname;
    private String email;
    private String phone;
    private String mobile;
    private List<String> groups;

    public User() {
        groups = new ArrayList<String>();
    }

    public User(final String login) {
        this.login = login;
        groups = new ArrayList<String>();
    }

    public String getLogin() {
        return login;
    }

    public void setLogin(String login) {
        this.login = login;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    public void setAndValidatePassword(String password) throws SimplePasswordException, NoSuchAlgorithmException {
        final PasswordValidator validator = new PasswordValidator();
        validator.validate(password);
        this.password = validator.createSaltedSHA512Hash(password);
    }

    public String getFirstname() {
        return firstname;
    }

    public void setFirstname(String firstname) {
        this.firstname = firstname;
    }

    public String getLastname() {
        return lastname;
    }

    public void setLastname(String lastname) {
        this.lastname = lastname;
    }

    public String getDisplayname() {
        return displayname;
    }

    public void setDisplayname(String displayname) {
        this.displayname = displayname;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }

    public List<String> getGroups() {
        return groups;
    }

    public void setGroups(List<String> groups) {
        this.groups = groups;
    }

    @Override
    public String toString() {
        return getFirstname() + " " + getLastname() + " (" + getLogin() + ", " + getEmail() + ")"; 
    }

    @Override
    public String getDn() {
        return dn;
    }

    @Override
    public void setDn(String dn) {
        this.dn = dn;
    }
}
