package de.jalin.ldapadmin.ldap;

import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;
import java.util.logging.Level;
import java.util.logging.Logger;

public class LDAPConfig {

    private static LDAPConfig config = null;

    private String ldapProviderUrl;
    private String ldapSecurityPrincipal;
    private String ldapSecurityPassword;
    private String smtpFromAddress;
    private String smtpHost;
    private String smtpPort;
    private String pacAdmin;
    private String pacPassword;
    private String tempDir;

    private LDAPConfig() {
        ldapProviderUrl = "ldap://localhost:10389/dc=domain,dc=example,dc=com";
        ldapSecurityPrincipal = "uid=admin,ou=system";
        ldapSecurityPassword = "secret";
        smtpHost = "localhost";
        smtpPort = "25";
        smtpFromAddress = "nobody@example.com";
        tempDir = System.getProperty("java.io.tmpdir");
        try {
            final Properties props = loadConfig();
            ldapProviderUrl = props.getProperty("provider.url", ldapProviderUrl);
            ldapSecurityPrincipal = props.getProperty("security.principal", ldapSecurityPrincipal);
            ldapSecurityPassword = props.getProperty("security.password", ldapSecurityPassword);
            smtpHost = props.getProperty("smtp.host", smtpHost);
            smtpPort = props.getProperty("smtp.port", smtpPort);
            smtpFromAddress = props.getProperty("smtp.from", smtpFromAddress);
            pacAdmin = props.getProperty("pac.user", "xyz00");
            pacPassword = props.getProperty("pac.password", "secret");
            tempDir = props.getProperty("temp.dir", tempDir);
        } catch (IOException ex) {
            Logger.getLogger(LDAPConfig.class.getName()).log(Level.SEVERE, null, ex);
        }
    }
    
    public static LDAPConfig getConfig() {
        if (config == null) {
            config = new LDAPConfig();
        }
        return config;
    }

    public String getLdapProviderUrl() {
        return ldapProviderUrl;
    }
    
    public String getLdapSecurityPrincipal() {
        return ldapSecurityPrincipal;
    }

    public String getLdapSecurityPassword() {
        return ldapSecurityPassword;
    }

    public String getSmtpHost() {
        return smtpHost;
    }

    public String getSmtpPort() {
        return smtpPort;
    }

    public String getSmtpFromAddress() {
        return smtpFromAddress;
    }

    public String getTempDir() {
        return tempDir;
    }

	public String getPacAdmin() {
		return pacAdmin;
	}

	public String getPacPassword() {
		return pacPassword;
	}

    private Properties loadConfig() throws IOException {
        final InputStream inputStream = this.getClass().getClassLoader().getResourceAsStream("config.properties");
        Properties config = new Properties();
        config.load(inputStream);
        return config;
    }

}
