package de.jalin.ldapadmin.tools;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.SortedMap;

import javax.naming.NamingException;

import org.apache.commons.csv.CSVFormat;
import org.apache.commons.csv.CSVParser;
import org.apache.commons.csv.CSVRecord;

import de.jalin.ldapadmin.beans.User;
import de.jalin.ldapadmin.ldap.AlreadyBoundException;
import de.jalin.ldapadmin.ldap.LDAPConfig;
import de.jalin.ldapadmin.ldap.LDAPSession;
import de.jalin.ldapadmin.ldap.LDAPSessionException;
import de.jalin.ldapadmin.ldap.RequiredAttributeException;
import de.jalin.ldapadmin.ldap.UsersDAO;

public class ImportUsersFromCSV {

	public static void main(String[] args) {
		LDAPSession ldapSession = null;
		if (args.length != 2) {
			System.out.println("usage:");
			System.out.println("ImportUsersFromCSV command csvfile");
			System.out.println("valid commands: verfiy, import");
			return;
		}
		try {
			ldapSession = connectLDAP();
			System.out.println("connected " + ldapSession.getSessionInfo());
			final UsersDAO usersDAO = new UsersDAO(ldapSession);
			final SortedMap<String,User> users = usersDAO.loadUsers();
			System.out.println("existing users: " + users.size());
			final File csvFile = new File(args[1]);
			final InputStreamReader csvStreamReader = new InputStreamReader(new FileInputStream(csvFile));
			final CSVParser csvParser = CSVFormat.DEFAULT.parse(csvStreamReader);
			for (CSVRecord record : csvParser) {
				final String userid = record.get(0);
				final String email = record.get(1);
				final String firstname = record.get(2);
				final String lastname = record.get(3);
				System.out.println(userid + "/" + email);
				final User user = new User(userid);
				user.setEmail(email);
				user.setFirstname(firstname);
				user.setLastname(lastname);
				user.setPassword(PasswordTool.generatePassword());
				try {
					usersDAO.create(user);
				} catch (RequiredAttributeException | AlreadyBoundException e) {
					System.err.println("user failed: " + userid + " => " + e.getLocalizedMessage());
				}
			}
		} catch (LDAPSessionException | IOException e) {
			System.err.println(e.getLocalizedMessage());
		} finally {
			if (ldapSession != null) {
				try { ldapSession.close(); } catch (NamingException e) { }
			}
		}
	}

	private static LDAPSession connectLDAP() throws LDAPSessionException {
		final LDAPConfig config = LDAPConfig.getConfig();
		final String providerUrl = config.getLdapProviderUrl();
		final String securityPrincipal = config.getLdapSecurityPrincipal();
		final String securityPassword = config.getLdapSecurityPassword();
		return  new LDAPSession(providerUrl, securityPrincipal, securityPassword);
	}
	
}
