package de.jalin.ldapadmin.tools;

import de.jalin.ldapadmin.ldap.SimplePasswordException;

public final class PasswordTool {
	
	public static final int MIN_COMPLEXITY = 3;
	public static final int MIN_PASSWORD_LENGTH = 6;
	
	private static final PasswordGenerator passwordGenerator = new PasswordGenerator.PasswordGeneratorBuilder()
	        .useDigits(true)
	        .useLower(true)
	        .useUpper(true)
	        .build();

	public static String generatePassword() {
		return passwordGenerator.generate(14);
	}
	
	public static void checkPasswordComplexity(final String password) throws SimplePasswordException {
		int containsLowercaseCharacter = 0;
		int containsUppercaseCharacter = 0;
		int containsSpecialCharacter = 0;
		int containsDigit = 0;
		for (int idx = 0;  idx < password.length(); idx++) {
			char chr = password.charAt(idx);
			if (chr >= 'a' && chr <= 'z') {
				containsLowercaseCharacter = 1;
			} else
			if (chr >= 'A' && chr <= 'Z') {
				containsUppercaseCharacter = 1;
			} else
			if (chr >= '0' && chr <= '1') {
				containsDigit = 1;
			} else {
				containsSpecialCharacter = 1;
			}
		}
		int complexity = containsLowercaseCharacter + containsUppercaseCharacter
				+ containsSpecialCharacter + containsDigit;
		if (complexity < MIN_COMPLEXITY || password.length() < MIN_PASSWORD_LENGTH) {
			throw new SimplePasswordException("simple password");
		}
	}
	
}
