package de.jalin.ldapadmin.web;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.SortedMap;

import javax.servlet.ServletException;
import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import de.jalin.ldapadmin.beans.Group;
import de.jalin.ldapadmin.beans.User;
import de.jalin.ldapadmin.ldap.AlreadyBoundException;
import de.jalin.ldapadmin.ldap.GroupsDAO;
import de.jalin.ldapadmin.ldap.LDAPSessionException;
import de.jalin.ldapadmin.ldap.NoGroupMembersException;
import de.jalin.ldapadmin.ldap.UsersDAO;

@WebServlet(name = "LdapGroup", urlPatterns = {"/group/*"}, loadOnStartup = 1)
public class GroupServlet extends AbstractLDAPServlet {

    private static final long serialVersionUID = 1L;

    @Override
    protected void doGet(final HttpServletRequest req, final HttpServletResponse resp)
            throws ServletException, IOException {
        final String pathInfo = req.getPathInfo();
        String groupDN = ""; 
        if (pathInfo != null && pathInfo.length() > 1 && pathInfo.charAt(0) == '/') {
            groupDN = pathInfo.substring(1);
        }
        final HttpSession httpSession = req.getSession();
        cleanSession(httpSession);
        String operation = req.getParameter("op");
        if (operation == null || operation.isEmpty()) {
            operation = "view";
        }
        httpSession.setAttribute("operation", operation);
        httpSession.setAttribute("formdisabled", "view".equals(operation) || "delete".equals(operation) ? "disabled" : "");
        httpSession.setAttribute("iddisabled", "create".equals(operation) ? "" : "disabled");

        final GroupsDAO groupsDAO = new GroupsDAO(ldapSession);
        final UsersDAO usersDAO = new UsersDAO(ldapSession);
        try {
            final SortedMap<String, User> users = usersDAO.loadUsers();
            httpSession.setAttribute("users", users); 
            if (groupDN != null && groupDN.length() > 9) {
                httpSession.setAttribute("group", groupsDAO.readGroup(groupDN, users)); 
            } else {
                httpSession.setAttribute("group", new Group()); 
            }
        } catch (LDAPSessionException e) {
            throwServletException(httpSession, e);
        }
        req.getRequestDispatcher("/group.jsp").forward(req, resp); 
    }

    @Override
    protected void doPost(HttpServletRequest req, HttpServletResponse resp)
            throws ServletException, IOException {
        final Messages messages = new Messages(req.getLocale());
        final String pathInfo = req.getPathInfo();
        String dn = ""; 
        if (pathInfo != null && pathInfo.length() > 1 && pathInfo.charAt(0) == '/') {
            dn = pathInfo.substring(1);
        }
        String operation = req.getParameter("op"); 
        if (operation == null || operation.isEmpty()) {
            operation = "none";
        }
        final GroupsDAO groupsDAO = new GroupsDAO(ldapSession);
        final Group grp = new Group();
        final List<String> members;
        members = new ArrayList<>();
        final HttpSession httpSession = req.getSession();
        cleanSession(httpSession);
        @SuppressWarnings("unchecked")
        final SortedMap<String, User> usersHash = (SortedMap<String, User>) httpSession.getAttribute("users"); 
        final Iterator<String> userDNIterator = usersHash.keySet().iterator();
        while (userDNIterator.hasNext()) {
            final String userDN = userDNIterator.next();
            final User usr = usersHash.get(userDN);
            final String isChecked = req.getParameter("check_user_" + usr.getLogin());
            if (isChecked != null && !isChecked.isEmpty()) {
                members.add(usr.getDn());
            }
        }
        grp.setMembers(members);
        try {
            if ("edit".equals(operation) && !dn.isEmpty()) { 
                final Group oldValue = groupsDAO.readGroup(dn, usersHash);
                grp.setDn(dn);
                grp.setName(oldValue.getName());
                if (grp.getMembers().isEmpty()) {
                    httpSession.setAttribute("group", grp);
                    httpSession.setAttribute("errormessage", messages.getString("GroupServlet.no_empty_group"));
                    req.getRequestDispatcher("/group.jsp").forward(req, resp); 
                    return;
                }
                try {
                    groupsDAO.update(grp);
                } catch (NoGroupMembersException e) {
                    httpSession.setAttribute("group", grp); 
                    httpSession.setAttribute("errormessage", messages.getString("GroupServlet.no_empty_group")); 
                    req.getRequestDispatcher("/group.jsp").forward(req, resp);
                    return;
                }
            }
            if ("delete".equals(operation) && !dn.isEmpty()) {
                final Group oldValue = groupsDAO.readGroup(dn, usersHash);
                grp.setDn(dn);
                grp.setName(oldValue.getName());
                groupsDAO.delete(grp);
            }
            if ("create".equals(operation)) { 
                final String grpName = req.getParameter("name");
                grp.setName(grpName);
                if (grp.getMembers().isEmpty()) {
                    httpSession.setAttribute("group", grp);
                    httpSession.setAttribute("errormessage", messages.getString("GroupServlet.no_empty_group"));
                    req.getRequestDispatcher("/group.jsp").forward(req, resp); 
                    return;
                }
                try {
                    groupsDAO.create(grp);
                } catch (AlreadyBoundException e) {
                    httpSession.setAttribute("group", grp); 
                    httpSession.setAttribute("errormessage", messages.getString("GroupServlet.group_exists"));
                    req.getRequestDispatcher("/group.jsp").forward(req, resp);
                    return;
                }
                resp.sendRedirect(req.getContextPath() + req.getServletPath() + "/" + grp.getDn()); 
            } else {
                if ("delete".equals(operation)) { 
                    resp.sendRedirect(req.getContextPath() + "/groups"); 
                } else {
                    resp.sendRedirect(req.getContextPath() + req.getServletPath() + pathInfo);
                }
            }
        } catch (LDAPSessionException e) {
            throwServletException(httpSession, e);
        }
    }

}
