package de.jalin.ldapadmin.web;

import java.io.IOException;
import java.util.SortedMap;

import javax.servlet.ServletException;
import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import de.jalin.ldapadmin.beans.Group;
import de.jalin.ldapadmin.beans.User;
import de.jalin.ldapadmin.ldap.GroupsDAO;
import de.jalin.ldapadmin.ldap.LDAPSessionException;
import de.jalin.ldapadmin.ldap.UsersDAO;

@WebServlet(name = "LdapUsers", urlPatterns = {"/users"}, loadOnStartup = 1)
public class UsersServlet extends AbstractLDAPServlet {

    private static final long serialVersionUID = 1L;

    @Override
    protected void doGet(final HttpServletRequest req, final HttpServletResponse resp)
            throws ServletException, IOException {
        final HttpSession httpSession = req.getSession();
        cleanSession(httpSession);
        final UsersDAO usersDAO = new UsersDAO(ldapSession);
        final GroupsDAO groupsDAO = new GroupsDAO(ldapSession);
        try {
            final SortedMap<String, User> users = usersDAO.loadUsers();
            final SortedMap<String, Group> groups = groupsDAO.loadGroups(users);
            httpSession.setAttribute("users", users);
            httpSession.setAttribute("groups", groups);
        } catch (LDAPSessionException e) {
            throwServletException(httpSession, e);
        }
        req.getRequestDispatcher("/users.jsp").forward(req, resp);
    }

}
