package de.jalin.ldapadmin.ldap;

import static org.junit.Assert.*;

import java.util.Arrays;

import org.junit.After;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;

import de.jalin.ldapadmin.beans.Group;
import de.jalin.ldapadmin.beans.User;

public class TestCreateGroup {

    private static final String USERS_DN = "uid=${uid},ou=users,dc=domain,dc=example,dc=com";

    private LDAPSession session;

    @BeforeClass
    public static void setupClass() throws Exception {
        DirectoryServiceRunner.assureServiceRunning("domain");
    }

    @Before
    public void setUp() throws Exception {
        session = new LDAPSession("ldap://localhost:10389/dc=domain,dc=example,dc=com", "uid=admin,ou=system", "streng-geheim");
    }

    @After
    public void tearDown() throws Exception {
        session.close();
        session = null;
    }

    @Test
    public void test() {
        final UsersDAO udao = new UsersDAO(session);
        final GroupsDAO gdao = new GroupsDAO(session);
        try {
            final User newUser1 = newUsersInstance("Jan", "Janssen");
            udao.create(newUser1);
            final User newUser2 = newUsersInstance("Jens", "Jenssen");
            udao.create(newUser2);
            Group login = new Group();
            login.setName("xlogin");
            login.setMembers(Arrays.asList(new String[]{newUser1.getDn(), newUser2.getDn()}));
            gdao.create(login);
            Group admins = new Group();
            admins.setName("xadmins");
            admins.setMembers(Arrays.asList(new String[]{newUser1.getDn(), newUser2.getDn()}));
            gdao.create(admins);
        } catch (LDAPSessionException | RequiredAttributeException | AlreadyBoundException e) {
            fail(e.getMessage());
        }
    }

    private User newUsersInstance(final String fn, final String ln) {
        final String uid = fn.substring(0, 3).toLowerCase();
        final User newUser = new User();
        newUser.setDn(USERS_DN.replace("${uid}", uid));
        newUser.setDisplayname(fn + " " + ln);
        newUser.setEmail(fn.toLowerCase() + "." + ln.toLowerCase() + "@example.com");
        newUser.setFirstname(fn);
        newUser.setLastname(ln);
        newUser.setLogin(uid);
        newUser.setMobile("0163 1234567");
        newUser.setPhone("030 12345678");
        newUser.setPassword("geheim");
        return newUser;
    }

}
