package de.jalin.ldapadmin.ldap;

import static org.junit.Assert.*;

import org.junit.After;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;

import de.jalin.ldapadmin.beans.User;

public class TestCreateUser {

    private static final String USERS_DN = "uid=pet,ou=users,dc=domain,dc=example,dc=com";

    private LDAPSession session;

    @BeforeClass
    public static void setupClass() throws Exception {
        DirectoryServiceRunner.assureServiceRunning("domain");
    }

    @Before
    public void setUp() throws Exception {
        session = new LDAPSession("ldap://localhost:10389/dc=domain,dc=example,dc=com", "uid=admin,ou=system", "streng-geheim");
    }

    @After
    public void tearDown() throws Exception {
        session.close();
        session = null;
    }

    @Test
    public void test() {
        final UsersDAO dao = new UsersDAO(session);
        try {
            final User existingUser = dao.loadUsers().get(USERS_DN);
            assertNull("user already exists", existingUser);
            final User newUser = new User();
            newUser.setDn(USERS_DN);
            newUser.setDisplayname("Peter Petersen");
            newUser.setEmail("peter.petersen@example.com");
            newUser.setFirstname("Peter");
            newUser.setLastname("Petersen");
            newUser.setLogin("pet");
            newUser.setMobile("0163 1234567");
            newUser.setPhone("030 12345678");
            newUser.setPassword("geheim");
            dao.create(newUser);
            final User createdUser = dao.loadUsers().get(USERS_DN);
            assertNotNull("should exist", createdUser);
            assertTrue("peter.petersen@example.com".equals(createdUser.getEmail()));
        } catch (LDAPSessionException | RequiredAttributeException | AlreadyBoundException e) {
            fail(e.getMessage());
        }
    }

}
