package de.jalin.ldapadmin.ldap;

import static org.junit.Assert.*;

import org.junit.After;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;

import de.jalin.ldapadmin.beans.User;

public class TestDeleteUser {

    private static final String USERS_DN = "uid=hei,ou=users,dc=domain,dc=example,dc=com";

    private LDAPSession session;

    @BeforeClass
    public static void setupClass() throws Exception {
        DirectoryServiceRunner.assureServiceRunning("domain");
    }

    @Before
    public void setUp() throws Exception {
        session = new LDAPSession("ldap://localhost:10389/dc=domain,dc=example,dc=com", "uid=admin,ou=system", "streng-geheim");
    }

    @After
    public void tearDown() throws Exception {
        session.close();
        session = null;
    }

    @Test
    public void test() {
        final UsersDAO dao = new UsersDAO(session);
        try {
            final User existingUser = dao.loadUsers().get(USERS_DN);
            assertNull("user already exists", existingUser);
            final User newUser = new User();
            newUser.setDn(USERS_DN);
            newUser.setDisplayname("Hein Hanssen");
            newUser.setEmail("hein.hanssen@example.com");
            newUser.setFirstname("Hein");
            newUser.setLastname("Hanssen");
            newUser.setLogin("hei");
            newUser.setMobile("0163 4434567");
            newUser.setPhone("030 44345678");
            newUser.setPassword("geheim");
            dao.create(newUser);
            final User createdUser = dao.loadUsers().get(USERS_DN);
            assertNotNull("should exist", createdUser);
            dao.delete(createdUser);
            final User deletedUser = dao.loadUsers().get(USERS_DN);
            assertNull("should be removed", deletedUser);
        } catch (LDAPSessionException | RequiredAttributeException | AlreadyBoundException e) {
            fail(e.getMessage());
        }
    }

}
